@@ -24,11 +24,6 @@
 #include "sort.h"
 #include "buffy.h"
 
-#ifdef USE_IMAP
-#include "mx.h"
-#include "imap.h"
-#endif
-
 
 
 
@@ -286,8 +281,7 @@ int mutt_index_menu (void)
   int do_buffy_notify = 1;
   int close = 0; /* did we OP_QUIT or OP_EXIT out of this menu? */
   int attach_msg = option(OPTATTACHMSG);
-  int check_lock = 0;
-  
+
   menu = mutt_new_menu ();
   menu->menu = MENU_MAIN;
   menu->offset = 1;
@@ -323,7 +317,7 @@ int mutt_index_menu (void)
        */
       index_hint = (Context->vcount) ? CURHDR->index : 0;
 
-      if ((check = mx_check_mailbox (Context, &index_hint, check_lock)) < 0)
+      if ((check = mx_check_mailbox (Context, &index_hint)) < 0)
       {
 	if (!Context->path)
 	{
@@ -452,8 +446,6 @@ int mutt_index_menu (void)
       }
     }
 
-    check_lock = 0;
-    
     if (!attach_msg)
     {
      /* check for new mail in the incoming folders */
@@ -749,11 +741,6 @@ int mutt_index_menu (void)
 
 	if (query_quadoption (OPT_QUIT, _("Quit Mutt?")) == M_YES)
 	{ 
-#ifdef USE_IMAP
-          /* logout gracefully from the IMAP server */
-          if (Context && Context->magic == M_IMAP)
-            imap_set_logout (Context);
-#endif
 	  if (!Context || mx_close_mailbox (Context) == 0)
 	    done = 1;
 	  else
@@ -794,10 +781,6 @@ int mutt_index_menu (void)
 
       case OP_MAIN_SYNC_FOLDER:
 
-        check_lock = 1;	/* call mx_check_mailbox() with locking the 
-			 * nex time
-			 */
-
 	CHECK_MSGCOUNT;
 	CHECK_READONLY;
 	{
@@ -995,10 +978,6 @@ int mutt_index_menu (void)
 	{
 	  if (Context)
 	  {
-#ifdef USE_IMAP
-            if (Context->magic == M_IMAP)
-              imap_set_logout (Context);
-#endif
 	    mx_fastclose_mailbox (Context);
 	    safe_free ((void **) &Context);
 	  }
@@ -1150,7 +1129,7 @@ int mutt_index_menu (void)
 	    }
 	  }
 
-	  if (CUR->collapsed && (Sort & SORT_MASK) == SORT_THREADS)
+	  if ((Sort & SORT_MASK) == SORT_THREADS && CUR->collapsed)
 	  {
 	    if ((op == OP_MAIN_NEXT_UNREAD || op == OP_MAIN_PREV_UNREAD) &&
 		UNREAD (CUR))
@@ -1194,34 +1173,20 @@ int mutt_index_menu (void)
 
 	CHECK_MSGCOUNT;
 	CHECK_READONLY;
+	mutt_set_flag (Context, CURHDR, M_FLAG, !CURHDR->flagged);
 
-        if (tag)
-        {
-	  for (j = 0; j < Context->vcount; j++)
+	if (option (OPTRESOLVE))
+	{
+	  if ((menu->current = ci_next_undeleted (menu->current)) == -1)
 	  {
-	    if (Context->hdrs[Context->v2r[j]]->tagged)
-	      mutt_set_flag (Context, Context->hdrs[Context->v2r[j]],
-			     M_FLAG, !Context->hdrs[Context->v2r[j]]->flagged);
-	  }
-
-	  menu->redraw |= REDRAW_INDEX;
-	}
-        else
-        {
-	  mutt_set_flag (Context, CURHDR, M_FLAG, !CURHDR->flagged);
-	  if (option (OPTRESOLVE))
-	  {
-	    if ((menu->current = ci_next_undeleted (menu->current)) == -1)
-	    {
-	      menu->current = menu->oldcurrent;
-	      menu->redraw = REDRAW_CURRENT;
-	    }
-	    else
-	      menu->redraw = REDRAW_MOTION_RESYNCH;
+	    menu->current = menu->oldcurrent;
+	    menu->redraw = REDRAW_CURRENT;
 	  }
 	  else
-	    menu->redraw = REDRAW_CURRENT;
+	    menu->redraw = REDRAW_MOTION_RESYNCH;
 	}
+	else
+	  menu->redraw = REDRAW_CURRENT;
 	menu->redraw |= REDRAW_STATUS;
 	break;
 
@@ -1316,23 +1281,6 @@ int mutt_index_menu (void)
 	  menu->redraw = REDRAW_MOTION;
 	break;
 
-      case OP_MAIN_PARENT_MESSAGE:
-
-	CHECK_MSGCOUNT;
-
-	if ((menu->current = mutt_parent_message (Context, CURHDR)) < 0)
-	{
-	  menu->current = menu->oldcurrent;
-	}
-	else if (menu->menu == MENU_PAGER)
-        {
-          op = OP_DISPLAY_MESSAGE;
-          continue;
-        }
-        else
-          menu->redraw = REDRAW_MOTION;
-	break;
-
       case OP_MAIN_SET_FLAG:
       case OP_MAIN_CLEAR_FLAG:
 
@@ -1463,15 +1411,11 @@ int mutt_index_menu (void)
 	if (tag)
 	{
 	  mutt_tag_set_flag (M_DELETE, 1);
-	  if (option (OPTDELETEUNTAG))
-	    mutt_tag_set_flag (M_TAG, 0);
 	  menu->redraw = REDRAW_INDEX;
 	}
 	else
 	{
 	  mutt_set_flag (Context, CURHDR, M_DELETE, 1);
-	  if (option (OPTDELETEUNTAG))
-	    mutt_set_flag (Context, CURHDR, M_TAG, 0);
 	  if (option (OPTRESOLVE))
 	  {
 	    if ((menu->current = ci_next_undeleted (menu->current)) == -1)
@@ -1514,7 +1458,7 @@ int mutt_index_menu (void)
       case OP_DISPLAY_ADDRESS:
 
 	CHECK_MSGCOUNT;
-	mutt_display_address (CURHDR->env);
+	mutt_display_address (CURHDR->env->from);
 	break;
 
       case OP_ENTER_COMMAND:
@@ -1533,10 +1477,11 @@ int mutt_index_menu (void)
 	CHECK_MSGCOUNT;
 	CHECK_READONLY;
 	CHECK_ATTACH;
-
-        mutt_edit_message (Context, tag ? NULL : CURHDR);
+        
+        set_option(OPTUSEHEADERDATE);
+	ci_send_message (SENDEDITMSG, NULL, NULL, Context, CURHDR);
+        unset_option(OPTUSEHEADERDATE);
 	menu->redraw = REDRAW_FULL;
-
 	break;
 
       case OP_FORWARD_MESSAGE:
@@ -1628,26 +1573,6 @@ int mutt_index_menu (void)
 	menu->redraw = REDRAW_FULL;
 	break;
 
-      case OP_RESEND:
-      
-        CHECK_ATTACH;
-        CHECK_MSGCOUNT;
-      
-        if (tag)
-        {
-	  for (j = 0; j < Context->vcount; j++)
-	  {
-	    if (Context->hdrs[Context->v2r[j]]->tagged)
-	      ci_send_message (SENDRESEND, NULL, NULL, Context,
-			       Context->hdrs[Context->v2r[j]]);
-	  }
-	}
-        else
-	  ci_send_message (SENDRESEND, NULL, NULL, Context, CURHDR);
-      
-        menu->redraw = REDRAW_FULL;
-        break;
-      
       case OP_REPLY:
 
 	CHECK_ATTACH;
@@ -1751,9 +1676,7 @@ int mutt_index_menu (void)
     {
       menu->menu = MENU_MAIN;
       menu->redraw = REDRAW_FULL;
-#if 0
       set_option (OPTWEED); /* turn header weeding back on. */
-#endif
     }
 
     if (done) break;
