@@ -29,27 +29,19 @@
 #include <string.h>
 #include <locale.h>
 
-static int _mutt_is_mail_list (ADDRESS *addr, LIST *p)
+int mutt_is_mail_list (ADDRESS *addr)
 {
+  LIST *p;
+
   if (addr->mailbox)
   {
-    for (;p; p = p->next)
+    for (p = MailLists; p; p = p->next)
       if (mutt_strncasecmp (addr->mailbox, p->data, mutt_strlen (p->data)) == 0)
 	return 1;
   }
   return 0;
 }
 
-int mutt_is_mail_list (ADDRESS *addr)
-{
-  return _mutt_is_mail_list (addr, MailLists);
-}
-
-int mutt_is_subscribed_list (ADDRESS *addr)
-{
-  return _mutt_is_mail_list (addr, SubscribedLists);
-}
-
 /* Search for a mailing list in the list of addresses pointed to by adr.
  * If one is found, print pfx and the name of the list into buf, then
  * return 1.  Otherwise, simply return 0.
@@ -59,7 +51,7 @@ check_for_mailing_list (ADDRESS *adr, char *pfx, char *buf, int buflen)
 {
   for (; adr; adr = adr->next)
   {
-    if (mutt_is_subscribed_list (adr))
+    if (mutt_is_mail_list (adr))
     {
       if (pfx && buf && buflen)
 	snprintf (buf, buflen, "%s%s", pfx, mutt_get_name (adr));
@@ -78,7 +70,7 @@ check_for_mailing_list_addr (ADDRESS *adr, char *buf, int buflen)
 {
   for (; adr; adr = adr->next)
   {
-    if (mutt_is_subscribed_list (adr))
+    if (mutt_is_mail_list (adr))
     {
       if (buf && buflen)
 	snprintf (buf, buflen, "%s", adr->mailbox);
@@ -93,7 +85,7 @@ static int first_mailing_list (char *buf, size_t buflen, ADDRESS *a)
 {
   for (; a; a = a->next)
   {
-    if (mutt_is_subscribed_list (a))
+    if (mutt_is_mail_list (a))
     {
       mutt_save_path (buf, buflen, a);
       return 1;
@@ -409,14 +401,9 @@ hdr_format_str (char *dest,
       break;
 
     case 'F':
-      if (!optional)
-      {
-        snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
-        make_from (hdr->env, buf2, sizeof (buf2), 0);
-        snprintf (dest, destlen, fmt, buf2);
-      }
-      else if (mutt_addr_is_user (hdr->env->from))
-        optional = 0;
+      snprintf (fmt, sizeof (fmt), "%%%ss", prefix);
+      make_from (hdr->env, buf2, sizeof (buf2), 0);
+      snprintf (dest, destlen, fmt, buf2);
       break;
 
     case 'i':
