@@ -38,6 +38,7 @@ struct mapping_t Menus[] = {
  { "pager",	MENU_PAGER },
  { "postpone",	MENU_POST },
 
+  
 
   
   
@@ -533,6 +534,7 @@ void km_init (void)
 
 
 
+
   
   /* bindings for the line editor */
   create_bindings (OpEditor, MENU_EDITOR);
@@ -604,9 +606,8 @@ void km_init (void)
 
   km_bindkey ("<enter>", MENU_PAGER, OP_NEXT_LINE);
   
-  km_bindkey ("<return>", MENU_ALIAS, OP_GENERIC_SELECT_ENTRY);
-  km_bindkey ("<enter>",  MENU_ALIAS, OP_GENERIC_SELECT_ENTRY);
-  km_bindkey ("<space>", MENU_ALIAS, OP_TAG);
+  km_bindkey ("<return>", MENU_ALIAS, OP_TAG);
+  km_bindkey ("<enter>",  MENU_ALIAS, OP_TAG);
 
   km_bindkey ("<enter>", MENU_ATTACH, OP_VIEW_ATTACH);
   km_bindkey ("<enter>", MENU_COMPOSE, OP_VIEW_ATTACH);
