@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
- * Copyright (C) 1999   Thomas Roessler <roessler@guug.de>
+ * Copyright (C) 1996-9 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -37,21 +36,20 @@
 #include <getopt.h>
 #endif
 
-static const char *ReachingUs = N_("\
+const char *ReachingUs = N_("\
 To contact the developers, please mail to <mutt-dev@mutt.org>.\n");
 
-static const char *Notice = N_("\
+const char *Notice = N_("\
 Copyright (C) 1996-9 Michael R. Elkins and others.\n\
 Mutt comes with ABSOLUTELY NO WARRANTY; for details type `mutt -vv'.\n\
 Mutt is free software, and you are welcome to redistribute it\n\
 under certain conditions; type `mutt -vv' for details.\n");
 
-static const char *Copyright = N_("\
+const char *Copyright = N_("\
 Copyright (C) 1996-9 Michael R. Elkins <me@cs.hmc.edu>\n\
-Copyright (C) 1996-9 Brandon Long <blong@fiction.net>\n\
 Copyright (C) 1997-9 Thomas Roessler <roessler@guug.de>\n\
 Copyright (C) 1998-9 Werner Koch <wk@isil.d.shuttle.de>\n\
-Copyright (C) 1999   Brendan Cully <brendan@kublai.com>\n\
+Copyright (C) 1998-9 Ruslan Ermilov <ru@ucb.crimea.ua>\n\
 \n\
 Lots of others not mentioned here contributed lots of code,\n\
 fixes, and suggestions.\n\
@@ -116,7 +114,7 @@ static void show_version (void)
   struct utsname uts;
 
   printf ("Mutt %s (%s)\n", MUTT_VERSION, ReleaseDate);
-  puts (Notice);
+  puts (_(Notice));
 
   uname (&uts);
 
@@ -181,12 +179,6 @@ static void show_version (void)
         "-USE_IMAP  "
 #endif
 
-#ifdef USE_GSS
-	"+USE_GSS  "
-#else
-	"-USE_GSS  "
-#endif
-
 #ifdef USE_POP
 	"+USE_POP  "
 #else
@@ -331,15 +323,13 @@ int main (int argc, char **argv)
   textdomain (PACKAGE);
 #endif
 
-  setlocale (LC_CTYPE, "");
-
   mutt_error = mutt_nocurses_error;
   SRAND (time (NULL));
+  setlocale (LC_CTYPE, "");
   umask (077);
 
   memset (Options, 0, sizeof (Options));
-  memset (QuadOptions, 0, sizeof (QuadOptions));
-  
+
   while ((i = getopt (argc, argv, "a:b:F:f:c:d:e:H:s:i:hm:npRvxyzZ")) != EOF)
     switch (i)
     {
@@ -475,30 +465,6 @@ int main (int argc, char **argv)
     mutt_error = mutt_curses_error;
   }
 
-  /* Create the Maildir directory if it doesn't exist. */
-  if (!option (OPTNOCURSES) && Maildir)
-  {
-    struct stat sb;
-    char fpath[_POSIX_PATH_MAX];
-    char msg[STRING];
-
-    strfcpy (fpath, Maildir, sizeof (fpath));
-    mutt_expand_path (fpath, sizeof (fpath));
-#ifdef USE_IMAP
-    /* we're not connected yet - skip mail folder creation */
-    if (!mx_is_imap (fpath))
-#endif
-    if (stat (fpath, &sb) == -1 && errno == ENOENT)
-    {
-      snprintf (msg, sizeof (msg), _("%s does not exist. Create it?"), Maildir);
-      if (mutt_yesorno (msg, 1) == 1)
-      {
-	if (mkdir (fpath, 0700) == -1 && errno != EEXIST)
-	  mutt_error ( _("Can't create %s: %s."), Maildir, strerror (errno));
-      }
-    }
-  }
-
   if (sendflags & SENDPOSTPONED)
   {
     if (!option (OPTNOCURSES))
@@ -529,7 +495,7 @@ int main (int argc, char **argv)
       for (i = optind; i < argc; i++)
 	msg->env->to = rfc822_parse_adrlist (msg->env->to, argv[i]);
 
-      if (option (OPTAUTOEDIT) && !msg->env->to && !msg->env->cc)
+      if (!msg->env->to && !msg->env->cc)
       {
 	if (!option (OPTNOCURSES))
 	  mutt_endwin (NULL);
@@ -565,7 +531,7 @@ int main (int argc, char **argv)
       tempfile = safe_strdup (buf);
 
       if (draftFile)
-	msg->env = mutt_read_rfc822_header (fin, NULL, 1, 0);
+	msg->env = mutt_read_rfc822_header (fin, NULL, 1);
 
       if (tempfile)
       {
