@@ -325,9 +325,9 @@ static int include_forward (CONTEXT *ctx, HEADER *cur, FILE *out)
   if (option (OPTFORWDECODE))
   {
     cmflags |= M_CM_DECODE | M_CM_CHARCONV;
-    if (option (OPTWEED))
+    if (option (OPTFORWWEEDHEADER))
     {
-      chflags |= CH_WEED | CH_REORDER;
+      chflags |= CH_WEED;
       cmflags |= M_CM_WEED;
     }
   }
@@ -342,8 +342,10 @@ static int include_forward (CONTEXT *ctx, HEADER *cur, FILE *out)
 static int include_reply (CONTEXT *ctx, HEADER *cur, FILE *out)
 {
   char buffer[STRING];
-  int cmflags = M_CM_PREFIX | M_CM_DECODE | M_CM_CHARCONV;
-  int chflags = CH_DECODE;
+  int flags = M_CM_PREFIX | M_CM_DECODE | M_CM_CHARCONV;
+
+
+
 
 
   if (Attribution)
@@ -353,15 +355,9 @@ static int include_reply (CONTEXT *ctx, HEADER *cur, FILE *out)
     fputc ('\n', out);
   }
   if (!option (OPTHEADER))
-    cmflags |= M_CM_NOHEADER;
-  if (option (OPTWEED))
-  {
-    chflags |= CH_WEED;
-    cmflags |= M_CM_WEED;
-  }
-
+    flags |= M_CM_NOHEADER;
   mutt_parse_mime_message (ctx, cur);
-  mutt_copy_message (out, ctx, cur, cmflags, chflags);
+  mutt_copy_message (out, ctx, cur, flags, CH_DECODE);
   if (PostIndentString)
   {
     mutt_make_string (buffer, sizeof (buffer), PostIndentString, ctx, cur);
@@ -378,15 +374,8 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
 
   if (group && env->mail_followup_to)
   {
-    snprintf (prompt, sizeof (prompt), _("Follow-up to %s%s?"),
-	      env->mail_followup_to->mailbox,
-	      env->mail_followup_to->next ? "..." : "");
-
-    if (query_quadoption (OPT_MFUPTO, prompt) == M_YES)
-    {
-      rfc822_append (to, env->mail_followup_to);
-      return 0;
-    }
+    rfc822_append (to, env->mail_followup_to);
+    return 0;
   }
 
   if (!option(OPTREPLYSELF) && mutt_addr_is_user (env->from))
@@ -622,7 +611,6 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
 
     if (i == M_YES)
     {
-      mutt_message _("Including quoted message...");
       if (!cur)
       {
 	for (i = 0; i < ctx->vcount; i++)
@@ -641,17 +629,14 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
       }
       else
 	include_reply (ctx, cur, tempfp);
-
     }
   }
   else if (flags & SENDFORWARD)
   {
-    if ((i = query_quadoption (OPT_MIMEFWD, _("Forward MIME encapsulated?"))) == M_YES)
+    if (query_quadoption (OPT_MIMEFWD, _("Forward MIME encapsulated?")))
     {
       BODY *last = msg->content;
 
-      mutt_message _("Preparing forwarded message...");
-      
       while (last && last->next)
 	last = last->next;
 
@@ -681,7 +666,7 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
 	}
       }
     }
-    else if (i != -1)
+    else
     {
       if (cur)
 	include_forward (ctx, cur, tempfp);
@@ -690,14 +675,12 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
 	  if (ctx->hdrs[ctx->v2r[i]]->tagged)
 	    include_forward (ctx, ctx->hdrs[ctx->v2r[i]], tempfp);
     }
-    else if (i == -1)
-      return -1;
   }
 
 
 
 
-  mutt_clear_error ();
+
 
   return (0);
 }
@@ -707,8 +690,7 @@ void mutt_set_followup_to (ENVELOPE *e)
   ADDRESS *t = NULL;
 
   /* only generate the Mail-Followup-To if the user has requested it, and
-   * it hasn't already been set
-   */
+     it hasn't already been set */
   if (option (OPTFOLLOWUPTO) && !e->mail_followup_to)
   {
     if (mutt_is_list_recipient (0, e->to, e->cc))
@@ -757,30 +739,20 @@ static ADDRESS *set_reverse_name (ENVELOPE *env)
   return (tmp);
 }
 
-ADDRESS *mutt_default_from (void)
+static ADDRESS *mutt_default_from (void)
 {
-  ADDRESS *adr;
+  ADDRESS *adr = rfc822_new_address ();
   const char *fqdn = mutt_fqdn(1);
+  
+  /* don't set realname here, it will be set later */
 
-  /* 
-   * Note: We let $from override $realname here.  Is this the right
-   * thing to do? 
-   */
-
-  if (From)
-    adr = rfc822_cpy_adr_real (From);
-  else if (option (OPTUSEDOMAIN))
+  if (option (OPTUSEDOMAIN))
   {
-    adr = rfc822_new_address ();
     adr->mailbox = safe_malloc (mutt_strlen (Username) + mutt_strlen (fqdn) + 2);
     sprintf (adr->mailbox, "%s@%s", NONULL(Username), NONULL(fqdn));
   }
   else
-  {
-    adr = rfc822_new_address ();
     adr->mailbox = safe_strdup (NONULL(Username));
-  }
-  
   return (adr);
 }
 
@@ -789,13 +761,13 @@ static int send_message (HEADER *msg)
   char tempfile[_POSIX_PATH_MAX];
   FILE *tempfp;
   int i;
-  
+
   /* Write out the message in MIME form. */
   mutt_mktemp (tempfile);
   if ((tempfp = safe_fopen (tempfile, "w")) == NULL)
     return (-1);
 
-  
+  mutt_write_rfc822_header (tempfp, msg->env, msg->content, 0);
   fputc ('\n', tempfp); /* tie off the header. */
 
   if ((mutt_write_mime_body (msg->content, tempfp) == -1))
@@ -812,7 +784,6 @@ static int send_message (HEADER *msg)
     return (-1);
   }
 
-
   i = mutt_invoke_sendmail (msg->env->to, msg->env->cc, msg->env->bcc,
 		       tempfile, (msg->content->encoding == ENC8BIT));
   return (i);
@@ -850,7 +821,6 @@ ci_send_message (int flags,		/* send mode */
   BODY *pbody;
   int i, killfrom = 0;
 
-
   if (!flags && !msg && quadoption (OPT_RECALL) != M_NO && mutt_num_postponed ())
   {
     /* If the user is composing a new message, check to see if there
@@ -875,9 +845,9 @@ ci_send_message (int flags,		/* send mode */
   {
     msg = mutt_new_header ();
 
-    if (flags == SENDRESEND)
+    if (flags == SENDEDITMSG)
     {
-      if (mutt_prepare_template (ctx, msg, cur, 1) < 0)
+      if (mutt_prepare_edit_message(ctx, msg, cur) < 0)
 	goto cleanup;
     }
     else if (flags == SENDPOSTPONED)
@@ -886,7 +856,7 @@ ci_send_message (int flags,		/* send mode */
 	goto cleanup;
     }
 
-    if (flags & (SENDPOSTPONED|SENDRESEND))
+    if (flags & (SENDPOSTPONED | SENDEDITMSG))
     {
       if ((tempfp = safe_fopen (msg->content->filename, "a+")) == NULL)
       {
@@ -899,7 +869,7 @@ ci_send_message (int flags,		/* send mode */
       msg->env = mutt_new_envelope ();
   }
 
-  if (! (flags & (SENDKEY | SENDPOSTPONED | SENDRESEND)))
+  if (! (flags & (SENDKEY | SENDPOSTPONED | SENDEDITMSG)))
   {
     pbody = mutt_new_body ();
     pbody->next = msg->content; /* don't kill command-line attachments */
@@ -931,7 +901,7 @@ ci_send_message (int flags,		/* send mode */
   }
 
   /* this is handled here so that the user can match ~f in send-hook */
-  if (cur && option (OPTREVNAME) && !(flags & (SENDPOSTPONED|SENDRESEND)))
+  if (cur && option (OPTREVNAME) && !(flags & (SENDPOSTPONED | SENDEDITMSG)))
   {
     /* we shouldn't have to worry about freeing `msg->env->from' before
      * setting it here since this code will only execute when doing some
@@ -940,7 +910,7 @@ ci_send_message (int flags,		/* send mode */
     msg->env->from = set_reverse_name (cur->env);
   }
 
-  if (!msg->env->from && option (OPTUSEFROM) && !(flags & (SENDPOSTPONED|SENDRESEND)))
+  if (!msg->env->from && option (OPTUSEFROM) && !(flags & (SENDEDITMSG|SENDPOSTPONED)))
     msg->env->from = mutt_default_from ();
 
   if (flags & SENDBATCH) 
@@ -952,7 +922,7 @@ ci_send_message (int flags,		/* send mode */
       process_user_header (msg->env);
     }
   }
-  else if (! (flags & (SENDPOSTPONED|SENDRESEND)))
+  else if (! (flags & (SENDPOSTPONED | SENDEDITMSG)))
   {
     if ((flags & (SENDREPLY | SENDFORWARD)) &&
 	envelope_defaults (msg->env, ctx, cur, flags) == -1)
@@ -1007,7 +977,7 @@ ci_send_message (int flags,		/* send mode */
   }
   /* wait until now to set the real name portion of our return address so
      that $realname can be set in a send-hook */
-  if (msg->env->from && !msg->env->from->personal && !(flags & (SENDRESEND|SENDPOSTPONED)))
+  if (msg->env->from && !msg->env->from->personal && !(flags & (SENDEDITMSG | SENDPOSTPONED)))
     msg->env->from->personal = safe_strdup (Realname);
 
 
@@ -1051,7 +1021,7 @@ ci_send_message (int flags,		/* send mode */
 	mutt_edit_file (Editor, msg->content->filename);
     }
 
-    if (! (flags & (SENDPOSTPONED | SENDFORWARD | SENDKEY | SENDRESEND)))
+    if (! (flags & (SENDPOSTPONED | SENDEDITMSG | SENDFORWARD | SENDKEY)))
     {
       if (stat (msg->content->filename, &st) == 0)
       {
@@ -1071,7 +1041,7 @@ ci_send_message (int flags,		/* send mode */
   /* specify a default fcc.  if we are in batchmode, only save a copy of
    * the message if the value of $copy is yes or ask-yes */
 
-  if (!fcc[0] && !(flags & (SENDRESEND|SENDPOSTPONED)) && (!(flags & SENDBATCH) || (quadoption (OPT_COPY) & 0x1)))
+  if (!fcc[0] && (!(flags & SENDBATCH) || (quadoption (OPT_COPY) & 0x1)))
   {
     /* set the default FCC */
     if (!msg->env->from)
@@ -1094,7 +1064,6 @@ ci_send_message (int flags,		/* send mode */
   {
 main_loop:
 
-    mutt_pretty_mailbox (fcc);
     i = mutt_compose_menu (msg, fcc, sizeof (fcc), cur);
     if (i == -1)
     {
@@ -1107,6 +1076,13 @@ main_loop:
       /* postpone the message until later. */
       if (msg->content->next)
 	msg->content = mutt_make_multipart (msg->content);
+
+      /*
+       * make sure the message is written to the right part of a maildir 
+       * postponed folder.
+       */
+      msg->read = 0; msg->old = 0;
+
       if (!Postponed || mutt_write_fcc (NONULL (Postponed), msg, (cur && (flags & SENDREPLY)) ? cur->env->message_id : NULL, 1, fcc) < 0)
       {
 	msg->content = mutt_remove_multipart (msg->content);
@@ -1148,6 +1124,12 @@ main_loop:
    * in case of error.  Ugh.
    */
 
+  if (flags & SENDEDITMSG)
+  {
+   int really_send = mutt_yesorno (_("Message edited. Really send?"), 1);
+   if (really_send != M_YES)
+     goto main_loop;
+  }
 
   if (!option (OPTNOCURSES) && !(flags & SENDMAILX))
     mutt_message _("Sending message...");
@@ -1156,7 +1138,6 @@ main_loop:
   encode_descriptions (msg->content);
 
   /* save a copy of the message, if necessary. */
-
   mutt_expand_path (fcc, sizeof (fcc));
   if (*fcc && mutt_strcmp ("/dev/null", fcc) != 0)
   {
@@ -1170,7 +1151,6 @@ main_loop:
 
     if (msg->content)
       mutt_write_fcc (fcc, msg, NULL, 0, NULL);
-
     msg->content = tmpbody;
 
   }
@@ -1192,7 +1172,6 @@ main_loop:
   else if (!option (OPTNOCURSES) && ! (flags & SENDMAILX))
     mutt_message (i == 0 ? _("Mail sent.") : _("Sending in background."));
 
-
   if (flags & SENDREPLY)
   {
     if (cur)
